@@ -256,7 +256,6 @@ static void alertpanel_create(const gchar *title,
 	gtk_window_set_resizable(GTK_WINDOW(dialog), TRUE);
 
 	gtk_window_set_default_size(GTK_WINDOW(dialog), 375, 100);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 	g_signal_connect(G_OBJECT(dialog), "delete_event",
@@ -326,7 +325,7 @@ static void alertpanel_create(const gchar *title,
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-	GTK_WIDGET_UNSET_FLAGS(label, GTK_CAN_FOCUS);
+	gtkut_widget_set_can_focus(label, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 		
