@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail teams
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail teams
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ Base64Decoder *base64_decoder_new	(void);
 void	       base64_decoder_free	(Base64Decoder	*decoder);
 gint	       base64_decoder_decode	(Base64Decoder	*decoder,
 					 const gchar	*in,
-					 guchar		*out);
+					 guchar		*out,
+					 gint           inlen);
 
 #endif /* __BASE64_H__ */
