@@ -368,7 +368,7 @@ static void addressbook_edit_group_create( gboolean *cancelled ) {
 	gtk_cmclist_set_auto_sort( GTK_CMCLIST(clist_group), TRUE );
 
 	for( i = 0; i < GROUP_N_COLS; i++ )
-		GTK_WIDGET_UNSET_FLAGS(GTK_CMCLIST(clist_group)->column[i].button, GTK_CAN_FOCUS);
+		gtkut_widget_set_can_focus(GTK_CMCLIST(clist_group)->column[i].button, FALSE);
 
 	/* Available list */
 	vboxl = gtk_vbox_new( FALSE, 0 );
@@ -406,7 +406,7 @@ static void addressbook_edit_group_create( gboolean *cancelled ) {
 	gtk_cmclist_set_auto_sort( GTK_CMCLIST(clist_avail), TRUE );
 
 	for( i = 0; i < GROUP_N_COLS; i++ )
-		GTK_WIDGET_UNSET_FLAGS(GTK_CMCLIST(clist_avail)->column[i].button, GTK_CAN_FOCUS);
+		gtkut_widget_set_can_focus(GTK_CMCLIST(clist_avail)->column[i].button, FALSE);
 
 	/* Status line */
 	hsbox = gtk_hbox_new(FALSE, 0);
