@@ -424,7 +424,8 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 		if (cmd == NULL)
 			return FALSE;
 		else {
-			system(cmd);
+			if (system(cmd) == -1)
+				g_warning("couldn't run %s", cmd);
 			g_free(cmd);
 		}
 		return TRUE;
@@ -822,9 +823,10 @@ static gboolean filter_msginfo(GSList * filtering_list, MsgInfo * info, PrefsAcc
 		}
 	}
 
-	/* put in inbox if a final rule could not be applied, or
-	 * the last rule was not a final one. */
-	if ((final && !apply_next) || !final) {
+    /* put in inbox if the last rule was not a final one, or
+     * a final rule could not be applied.
+     * Either of these cases is likely. */
+    if (!final || !apply_next) {
 		return FALSE;
 	}
 
