@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,6 +44,12 @@ struct _FolderItemPrefs {
 	gchar *default_to;
 	gboolean enable_default_reply_to;
 	gchar *default_reply_to;
+	gboolean enable_default_cc;
+	gchar *default_cc;
+	gboolean enable_default_bcc;
+	gchar *default_bcc;
+	gboolean enable_default_replyto;
+	gchar *default_replyto;
 	gboolean enable_simplify_subject;
 #ifndef G_OS_WIN32
 	gchar *simplify_subject_regexp;
@@ -52,12 +58,12 @@ struct _FolderItemPrefs {
 	gint folder_chmod;
 	gboolean enable_default_account;
 	gint default_account;
-#if USE_ENCHANT
+
 	gboolean enable_default_dictionary;
 	gchar *default_dictionary;
 	gboolean enable_default_alt_dictionary;
 	gchar *default_alt_dictionary;
-#endif
+
 	gboolean save_copy_to_folder;
 	guint color;
 
