@@ -970,13 +970,7 @@ static void inc_progress_dialog_set_progress(IncProgressDialog *inc_dialog,
 	progress_dialog_set_fraction
 		(inc_dialog->dialog, (total == 0) ? 0: (gfloat)cur_total / (gfloat)total);
 
-	g_snprintf(buf, sizeof(buf), "%d / %d",
-		   pop3_session->cur_msg, pop3_session->count);
-	gtk_progress_bar_set_text
-		(GTK_PROGRESS_BAR(inc_dialog->mainwin->progressbar), buf);
-	gtk_progress_bar_set_fraction
-		(GTK_PROGRESS_BAR(inc_dialog->mainwin->progressbar),
-		 (total == 0) ? 0 : (gfloat)cur_total / (gfloat)total);
+	statusbar_progress_all(pop3_session->cur_msg, pop3_session->count, 1);
 
 	if (pop3_session->cur_total_num > 0) {
 		g_snprintf(buf, sizeof(buf),
