@@ -1,5 +1,5 @@
 /* select-keys.c - GTK+ based key selection
- *      Copyright (C) 2001-2007 Werner Koch (dd9jn) and the Claws Mail team
+ *      Copyright (C) 2001-2009 Werner Koch (dd9jn) and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify        
  * it under the terms of the GNU General Public License as published by
@@ -183,7 +183,7 @@ set_row (GtkCMCList *clist, gpgme_key_t key, gpgme_protocol_t proto)
 
     /* first check whether the key is capable of encryption which is not
      * the case for revoked, expired or sign-only keys */
-    if (!key->can_encrypt || key->revoked || key->expired)
+    if (!key->can_encrypt || key->revoked || key->expired || key->disabled)
         return;
 
     algo_buf = g_strdup_printf ("%du/%s", 
@@ -274,9 +274,9 @@ fill_clist (struct select_keys_s *sk, const char *pattern, gpgme_protocol_t prot
     int num_results = 0;
     gboolean exact_match = FALSE;
     gpgme_key_t last_key = NULL;
-    g_return_val_if_fail (sk, NULL);
+    cm_return_val_if_fail (sk, NULL);
     clist = sk->clist;
-    g_return_val_if_fail (clist, NULL);
+    cm_return_val_if_fail (clist, NULL);
 
     debug_print ("select_keys:fill_clist:  pattern '%s' proto %d\n", pattern, proto);
 
@@ -302,7 +302,7 @@ fill_clist (struct select_keys_s *sk, const char *pattern, gpgme_protocol_t prot
     update_progress (sk, ++running, pattern);
     while ( !(err = gpgme_op_keylist_next ( ctx, &key )) ) {
 	gpgme_user_id_t uid = key->uids;
-	if (!key->can_encrypt || key->revoked || key->expired)
+	if (!key->can_encrypt || key->revoked || key->expired || key->disabled)
 		continue;
         debug_print ("%% %s:%d:  insert\n", __FILE__ ,__LINE__ );
         set_row (clist, key, proto ); 
@@ -415,13 +415,16 @@ create_dialog (struct select_keys_s *sk)
     hbox = gtk_hbox_new (FALSE, 8);
     gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
+    /* TRANSLATORS: check that the accelerators in _Select, _Other and
+     * Do_n't encrypt are different than the one in the stock Cancel
+     * button */
     gtkut_stock_button_set_create (&bbox, 
-                                   &select_btn, _("Select"),
-		   		   &other_btn, _("Other"),
-		    		   &dont_encrypt_btn, _("Don't encrypt"));
+                                   &select_btn, _("_Select"),
+		   		   &other_btn, _("_Other"),
+		    		   &dont_encrypt_btn, _("Do_n't encrypt"));
     
     cancel_btn = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-    GTK_WIDGET_SET_FLAGS(cancel_btn, GTK_CAN_DEFAULT);
+    gtkut_widget_set_can_default(cancel_btn, TRUE);
     gtk_box_pack_start(GTK_BOX(bbox), cancel_btn, TRUE, TRUE, 0);
     gtk_widget_show(cancel_btn);
     gtk_box_pack_end (GTK_BOX (hbox), bbox, FALSE, FALSE, 0);
@@ -460,7 +463,7 @@ open_dialog (struct select_keys_s *sk)
 static void
 close_dialog (struct select_keys_s *sk)
 {
-    g_return_if_fail (sk);
+    cm_return_if_fail (sk);
     gtk_widget_destroy (sk->window);
     sk->window = NULL;
 }
@@ -483,7 +486,7 @@ key_pressed_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
     struct select_keys_s *sk = data;
 
-    g_return_val_if_fail (sk, FALSE);
+    cm_return_val_if_fail (sk, FALSE);
     if (event && event->keyval == GDK_Escape) {
         sk->okay = 0;
         gtk_main_quit ();
@@ -500,7 +503,7 @@ select_btn_cb (GtkWidget *widget, gpointer data)
     gboolean use_key;
     gpgme_key_t key;
 
-    g_return_if_fail (sk);
+    cm_return_if_fail (sk);
     if (!sk->clist->selection) {
         debug_print ("** nothing selected");
         return;
@@ -532,7 +535,7 @@ cancel_btn_cb (GtkWidget *widget, gpointer data)
 {
     struct select_keys_s *sk = data;
 
-    g_return_if_fail (sk);
+    cm_return_if_fail (sk);
     sk->okay = 0;
     sk->result = KEY_SELECTION_CANCEL;
     if (sk->select_ctx)
@@ -545,7 +548,7 @@ dont_encrypt_btn_cb (GtkWidget *widget, gpointer data)
 {
     struct select_keys_s *sk = data;
 
-    g_return_if_fail (sk);
+    cm_return_if_fail (sk);
     sk->okay = 0;
     sk->result = KEY_SELECTION_DONT;
     if (sk->select_ctx)
@@ -559,7 +562,7 @@ other_btn_cb (GtkWidget *widget, gpointer data)
     struct select_keys_s *sk = data;
     char *uid;
 
-    g_return_if_fail (sk);
+    cm_return_if_fail (sk);
     uid = input_dialog ( _("Add key"),
                          _("Enter another user or key ID:"),
                          NULL );
