@@ -226,6 +226,9 @@ static PrefParam param[] = {
 	 &prefs_common.compose_subject_format, P_STRING, NULL, NULL, NULL},
 	{"compose_body_format", N_("Hello,\\n"),
 	 &prefs_common.compose_body_format, P_STRING, NULL, NULL, NULL},
+	{"show_compose_margin", "FALSE", &prefs_common.show_compose_margin, P_BOOL,
+	 NULL, NULL, NULL},
+	
 
 	{"linewrap_length", "72", &prefs_common.linewrap_len, P_INT,
 	 NULL, NULL, NULL},
@@ -730,6 +733,9 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"scroll_half_page", "FALSE", &prefs_common.scroll_halfpage, P_BOOL,
 	 NULL, NULL, NULL},
+	{"hide_quoted", "TRUE",
+	 &prefs_common.hide_quoted, P_BOOL,
+	 NULL, NULL, NULL},
 	{"respect_flowed_format", "FALSE", &prefs_common.respect_flowed_format, P_BOOL,
 	 NULL, NULL, NULL},
 
@@ -918,7 +924,7 @@ static PrefParam param[] = {
 	{"filtering_debug_log_length", "500", &prefs_common.filtering_debug_loglength, P_INT,
 	 NULL, NULL, NULL},
 
-	{"gtk_can_change_accels", "TRUE", &prefs_common.gtk_can_change_accels, P_BOOL,
+	{"gtk_can_change_accels", "FALSE", &prefs_common.gtk_can_change_accels, P_BOOL,
 	 NULL, NULL, NULL},
 
 	{"color_new", "#0000b3", &prefs_common.color_new, P_COLOR,
