@@ -157,6 +157,7 @@ struct _PrefsCommon
 	gboolean compose_with_format;
 	gchar *compose_subject_format;
 	gchar *compose_body_format;
+	gboolean show_compose_margin;
 
 	/* Quote */
 	gboolean reply_with_quote;
@@ -317,6 +318,7 @@ struct _PrefsCommon
 	gboolean enable_smooth_scroll;
 	gint scroll_step;
 	gboolean scroll_halfpage;
+	gboolean hide_quoted;
 	gboolean respect_flowed_format;
 
 	gboolean show_other_header;
