@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto & the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto & the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ void privacy_free_privacydata(PrivacyData *privacydata)
 {
 	PrivacySystem *system = NULL;
 	
-	g_return_if_fail(privacydata != NULL);
+	cm_return_if_fail(privacydata != NULL);
 
 	system = privacy_data_get_system(privacydata);
 	if (!system)
@@ -120,7 +120,7 @@ void privacy_free_privacydata(PrivacyData *privacydata)
 gboolean privacy_mimeinfo_is_signed(MimeInfo *mimeinfo)
 {
 	GSList *cur;
-	g_return_val_if_fail(mimeinfo != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
 
 	if (mimeinfo->privacy != NULL) {
 		PrivacySystem *system = 
@@ -147,26 +147,41 @@ try_others:
 	return FALSE;
 }
 
+struct SignedState {
+	MsgInfo *msginfo;
+	gchar **system;
+};
+
 static void msginfo_set_signed_flag(GNode *node, gpointer data)
 {
-	MsgInfo *msginfo = data;
+	struct SignedState *sstate = (struct SignedState *)data;
+	MsgInfo *msginfo = sstate->msginfo;
 	MimeInfo *mimeinfo = node->data;
 	
 	if (privacy_mimeinfo_is_signed(mimeinfo)) {
 		procmsg_msginfo_set_flags(msginfo, 0, MSG_SIGNED);
+		if (sstate->system && !*(sstate->system) && mimeinfo->privacy)
+			*(sstate->system) = g_strdup(mimeinfo->privacy->system->id);
 	}
 	if (privacy_mimeinfo_is_encrypted(mimeinfo)) {
 		procmsg_msginfo_set_flags(msginfo, 0, MSG_ENCRYPTED);
+		if (sstate->system && !*(sstate->system) && mimeinfo->privacy)
+			*(sstate->system) = g_strdup(mimeinfo->privacy->system->id);
 	} else {
 		/* searching inside encrypted parts doesn't really make sense */
-		g_node_children_foreach(mimeinfo->node, G_TRAVERSE_ALL, msginfo_set_signed_flag, msginfo);
+		g_node_children_foreach(mimeinfo->node, G_TRAVERSE_ALL, msginfo_set_signed_flag, sstate);
 	}
 }
 
-void privacy_msginfo_get_signed_state(MsgInfo *msginfo)
+void privacy_msginfo_get_signed_state(MsgInfo *msginfo, gchar **system)
 {
+	struct SignedState sstate;
 	MimeInfo *mimeinfo = procmime_scan_message(msginfo);
-	g_node_children_foreach(mimeinfo->node, G_TRAVERSE_ALL, msginfo_set_signed_flag, msginfo);
+	if (!mimeinfo)
+		return;
+	sstate.msginfo = msginfo;
+	sstate.system = system;
+	g_node_children_foreach(mimeinfo->node, G_TRAVERSE_ALL, msginfo_set_signed_flag, &sstate);
 }
 
 /**
@@ -181,7 +196,7 @@ gint privacy_mimeinfo_check_signature(MimeInfo *mimeinfo)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(mimeinfo != NULL, -1);
+	cm_return_val_if_fail(mimeinfo != NULL, -1);
 
 	if (mimeinfo->privacy == NULL)
 		privacy_mimeinfo_is_signed(mimeinfo);
@@ -203,7 +218,7 @@ SignatureStatus privacy_mimeinfo_get_sig_status(MimeInfo *mimeinfo)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(mimeinfo != NULL, -1);
+	cm_return_val_if_fail(mimeinfo != NULL, -1);
 
 	if (mimeinfo->privacy == NULL)
 		privacy_mimeinfo_is_signed(mimeinfo);
@@ -224,7 +239,7 @@ gchar *privacy_mimeinfo_sig_info_short(MimeInfo *mimeinfo)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
 
 	if (mimeinfo->privacy == NULL)
 		privacy_mimeinfo_is_signed(mimeinfo);
@@ -245,7 +260,7 @@ gchar *privacy_mimeinfo_sig_info_full(MimeInfo *mimeinfo)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(mimeinfo != NULL, NULL);
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
 
 	if (mimeinfo->privacy == NULL)
 		privacy_mimeinfo_is_signed(mimeinfo);
@@ -265,7 +280,7 @@ gchar *privacy_mimeinfo_sig_info_full(MimeInfo *mimeinfo)
 gboolean privacy_mimeinfo_is_encrypted(MimeInfo *mimeinfo)
 {
 	GSList *cur;
-	g_return_val_if_fail(mimeinfo != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
 
 	for(cur = systems; cur != NULL; cur = g_slist_next(cur)) {
 		PrivacySystem *system = (PrivacySystem *) cur->data;
@@ -282,7 +297,7 @@ static gint decrypt(MimeInfo *mimeinfo, PrivacySystem *system)
 	MimeInfo *decryptedinfo, *parentinfo;
 	gint childnumber;
 	
-	g_return_val_if_fail(system->decrypt != NULL, -1);
+	cm_return_val_if_fail(system->decrypt != NULL, -1);
 	
 	decryptedinfo = system->decrypt(mimeinfo);
 	if (decryptedinfo == NULL)
@@ -301,7 +316,9 @@ static gint decrypt(MimeInfo *mimeinfo, PrivacySystem *system)
 gint privacy_mimeinfo_decrypt(MimeInfo *mimeinfo)
 {
 	GSList *cur;
-	g_return_val_if_fail(mimeinfo != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
+
+	procmime_decode_content(mimeinfo);
 
 	for(cur = systems; cur != NULL; cur = g_slist_next(cur)) {
 		PrivacySystem *system = (PrivacySystem *) cur->data;
@@ -331,7 +348,7 @@ static PrivacySystem *privacy_get_system(const gchar *id)
 {
 	GSList *cur;
 
-	g_return_val_if_fail(id != NULL, NULL);
+	cm_return_val_if_fail(id != NULL, NULL);
 
 	for(cur = systems; cur != NULL; cur = g_slist_next(cur)) {
 		PrivacySystem *system = (PrivacySystem *) cur->data;
@@ -347,7 +364,7 @@ const gchar *privacy_system_get_name(const gchar *id)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(id != NULL, NULL);
+	cm_return_val_if_fail(id != NULL, NULL);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -360,7 +377,7 @@ gboolean privacy_system_can_sign(const gchar *id)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(id != NULL, FALSE);
+	cm_return_val_if_fail(id != NULL, FALSE);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -373,7 +390,7 @@ gboolean privacy_system_can_encrypt(const gchar *id)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(id != NULL, FALSE);
+	cm_return_val_if_fail(id != NULL, FALSE);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -386,8 +403,8 @@ gboolean privacy_sign(const gchar *id, MimeInfo *target, PrefsAccount *account,
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(id != NULL, FALSE);
-	g_return_val_if_fail(target != NULL, FALSE);
+	cm_return_val_if_fail(id != NULL, FALSE);
+	cm_return_val_if_fail(target != NULL, FALSE);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -403,9 +420,11 @@ gboolean privacy_sign(const gchar *id, MimeInfo *target, PrefsAccount *account,
 gchar *privacy_get_encrypt_data(const gchar *id, GSList *recp_names)
 {
 	PrivacySystem *system;
+	gchar *ret = NULL;
+	GSList *uniq_names = NULL, *cur;
 
-	g_return_val_if_fail(id != NULL, NULL);
-	g_return_val_if_fail(recp_names != NULL, NULL);
+	cm_return_val_if_fail(id != NULL, NULL);
+	cm_return_val_if_fail(recp_names != NULL, NULL);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -415,14 +434,22 @@ gchar *privacy_get_encrypt_data(const gchar *id, GSList *recp_names)
 	if (system->get_encrypt_data == NULL)
 		return NULL;
 
-	return system->get_encrypt_data(recp_names);
+	for (cur = recp_names; cur; cur = cur->next) {
+		if (!g_slist_find_custom(uniq_names, cur->data, (GCompareFunc)strcmp)) {
+			uniq_names = g_slist_prepend(uniq_names, cur->data);
+		}
+	}
+	ret = system->get_encrypt_data(uniq_names);
+	
+	g_slist_free(uniq_names);
+	return ret;
 }
 
 const gchar *privacy_get_encrypt_warning(const gchar *id)
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(id != NULL, NULL);
+	cm_return_val_if_fail(id != NULL, NULL);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -439,7 +466,7 @@ void privacy_inhibit_encrypt_warning(const gchar *id, gboolean inhibit)
 {
 	PrivacySystem *system;
 
-	g_return_if_fail(id != NULL);
+	cm_return_if_fail(id != NULL);
 
 	system = privacy_get_system(id);
 	if (system == NULL)
@@ -456,8 +483,8 @@ gboolean privacy_encrypt(const gchar *id, MimeInfo *mimeinfo, const gchar *encda
 {
 	PrivacySystem *system;
 
-	g_return_val_if_fail(id != NULL, FALSE);
-	g_return_val_if_fail(mimeinfo != NULL, FALSE);
+	cm_return_val_if_fail(id != NULL, FALSE);
+	cm_return_val_if_fail(mimeinfo != NULL, FALSE);
 	if (encdata == NULL) {
 		privacy_set_error(_("No recipient keys defined."));
 		return FALSE;
